@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "imgur" "1.1.0"
+(define-package "imgur" "20241201.1257"
   "Imgur client."
   '((emacs "27.1"))
   :url "https://github.com/KeyWeeUsr/imgur"
-  :commit "3eb96d58909c5c62613ee57495bdfe7e92d0c4b7"
-  :revdesc "1.1.0-0-g3eb96d58909c"
+  :commit "9a7f47d6da3f6a7365f8575c0403f05398ad05c5"
+  :revdesc "9a7f47d6da3f"
   :keywords '("convenience" "imgur" "client")
   :authors '(("Peter Badida" . "keyweeusr@gmail.com"))
   :maintainers '(("Peter Badida" . "keyweeusr@gmail.com")))
